pub struct SethHillLagrangian {
pub bulk_modulus: Quantity<Stress>,
pub shear_modulus: Quantity<Stress>,
pub exponent: Scalar,
}Expand description
The Lagrangian Seth-Hill elastic solid constitutive model.1,2
Parameters
- The bulk modulus $
\kappa$. - The shear modulus $
\mu$. - The exponent $
m$.
External variables
- The deformation gradient $
\mathbf{F}$.
Internal variables
- None.
Notes
- The Seth-Hill strain measure is given by $
\mathbf{E}^{(m)} = \tfrac{1}{m}(\mathbf{U}^m - \mathbf{1})$. - The model reduces to the elastic Hencky model when $
m=0$. - The model reduces to the hyperelastic Saint Venant-Kirchhoff model when $
m=2$. - The model reduces to the Lagrangian Almansi-Hamel model when $
m=-2$. - This is the Lagrangian counterpart of the Eulerian Seth-Hill model.
B.R. Seth, Generalized Strain Measure with Applications to Physical Problems, AD0266913 (1961). ↩
R. Hill, J. Mech. Phys. Solids 16, 229 (1968). ↩
Fields
bulk_modulus: Quantity<Stress>The bulk modulus $\kappa$.
shear_modulus: Quantity<Stress>The shear modulus $\mu$.
exponent: ScalarThe exponent $m$.
Implementations