pub struct BazantItskovEulerian {
pub bulk_modulus: Quantity<Stress>,
pub shear_modulus: Quantity<Stress>,
pub exponent: Scalar,
}Expand description
The Eulerian Bažant-Itskov elastic solid constitutive model.1,2
Parameters
- The bulk modulus $
\kappa$. - The shear modulus $
\mu$. - The exponent $
m$.
External variables
- The deformation gradient $
\mathbf{F}$.
Internal variables
- None.
Notes
- The Eulerian Bažant-Itskov strain measure is given by $
\mathbf{h}^{(m)} = \tfrac{1}{2m}(\mathbf{V}^m - \mathbf{V}^{-m})$. - The model reduces to the hyperelastic Hencky model when $
m=0$. - This is the Eulerian counterpart of the Lagrangian Bažant-Itskov model.
Z.P. Bažant, J. Eng. Mater. Technol. 120, 131 (1998). ↩
M. Itskov, Mech. Res. Commun. 31, 507 (2004). ↩
Fields
bulk_modulus: Quantity<Stress>The bulk modulus $\kappa$.
shear_modulus: Quantity<Stress>The shear modulus $\mu$.
exponent: ScalarThe exponent $m$.
Implementations